@@ -9,18 +9,16 @@ use Apache2::RequestIO ();
 
 sub handler {
   my $r = shift;
-  plan $r, tests => 6;
+  plan $r, tests => 5;
   
   eval{ require 5.006001;};
   ok t_cmp($@, "", "require 5.00601");
-  eval{ require mod_perl2;};
-  ok t_cmp($@, "", "require mod_perl2");
+
+  ok t_cmp($ENV{MOD_PERL_API_VERSION}, 2, "require mod_perl2");
   eval{ require Apache2::GeoIP;};
   ok t_cmp($@, "", "require Apache2::GeoIP");
   eval{ require Apache2::Geo::IP;};
   ok t_cmp($@, "", "require Apache2::Geo::IP");
-  eval{ require Apache2::Geo::IP::Record;};
-  ok t_cmp($@, "", "require Apache2::Geo::IP::Record");
   eval{ require Apache2::Geo::Mirror;};
   ok t_cmp($@, "", "require Apache2::Geo::Mirror");
   Apache2::Const::OK;
